LaneGroupError

Enum LaneGroupError 

pub enum LaneGroupError {
    DuplicateAddress {
        address: (u32, u32),
    },
    InvalidLane {
        message: String,
    },
    Inconsistent {
        message: String,
    },
    WordNotInSiteBusList {
        word_id: u32,
    },
    SiteNotInWordBusList {
        site_id: u32,
    },
    AODConstraintViolation {
        message: String,
    },
}

Variants



DuplicateAddress

A lane address appears more than once in the group.

Fields

address: (u32, u32)


InvalidLane

A lane address is invalid per the arch spec.

Fields

message: String


Inconsistent

Lanes have inconsistent bus_id, move_type, or direction.

Fields

message: String


WordNotInSiteBusList

Lane word_id not in words_with_site_buses.

Fields

word_id: u32


SiteNotInWordBusList

Lane site_id not in sites_with_word_buses.

Fields

site_id: u32


AODConstraintViolation

Lane group violates AOD grid constraint (e.g. not a complete grid).

Fields

message: String