pub fn validate_addresses(
program: &Program,
arch: &ArchSpec,
) -> Vec<ValidationError>Expand description
Validate addresses in the program against an architecture specification. Checks each constant location, lane, and zone instruction to ensure the encoded address refers to valid entries in the arch spec.