pub enum LaneGroupError {
DuplicateAddress {
address: (u32, u32),
},
InvalidLane {
message: String,
},
Inconsistent {
message: String,
},
WordNotInSiteBusList {
word_id: u32,
},
SiteNotInWordBusList {
site_id: u32,
},
AODConstraintViolation {
message: String,
},
}Variants
DuplicateAddress
A lane address appears more than once in the group.
InvalidLane
A lane address is invalid per the arch spec.
Inconsistent
Lanes have inconsistent bus_id, move_type, or direction.
WordNotInSiteBusList
Lane word_id not in words_with_site_buses.
SiteNotInWordBusList
Lane site_id not in sites_with_word_buses.
AODConstraintViolation
Lane group violates AOD grid constraint (e.g. not a complete grid).